"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var request = require("request");
var wechat_1 = require("../wechat");
var WeChat = /** @class */ (function () {
    function WeChat(bot) {
        this.bot = bot;
    }
    WeChat.prototype.send = function (message, filter) {
        var _this = this;
        var wechat = new wechat_1.WeChat(this.bot);
        return wechat.accessToken().then(function (token) {
            switch (message.type) {
                case 'text': {
                    var payload = {
                        msgtype: message.type,
                        text: {
                            content: message.content
                        },
                        touser: filter
                    };
                    return _this.sendRequest(token, payload);
                }
                case 'audio':
                case 'image':
                case 'video': {
                    message.type = message.type === "audio" ? "voice" : message.type;
                    var media = function () {
                        if (message.media_id) {
                            return Promise.resolve({
                                media_id: message.media_id
                            });
                        }
                        return wechat.uploadMedia(message.url, message.type).then(function (data) {
                            if (data.media_id) {
                                return {
                                    media_id: data.media_id
                                };
                            }
                        });
                    };
                    return media().then(function (file) {
                        var payload = {
                            msgtype: message.type,
                            touser: filter
                        };
                        payload[message.type] = file;
                        return _this.sendRequest(token, payload);
                    });
                }
                case 'news': {
                    var payload = {
                        msgtype: 'mpnews',
                        image: {
                            'media_id': message.assetId
                        },
                        touser: filter
                    };
                    return _this.sendRequest(token, payload);
                }
            }
        });
    };
    WeChat.prototype.sendRequest = function (token, payload) {
        return new Promise(function (resolve, reject) {
            request({
                json: true,
                method: "POST",
                url: "https://api.weixin.qq.com/cgi-bin/message/mass/send",
                qs: {
                    access_token: token
                },
                body: payload
            }, function (err, response, body) {
                if (err) {
                    return reject(err);
                }
                if (body.errcode !== 0) {
                    return reject({
                        code: body.errcode,
                        message: body.errmsg
                    });
                }
                resolve(body);
            });
        });
    };
    return WeChat;
}());
exports.WeChat = WeChat;
